@@ -1,3 +1,5 @@
+import asyncio
+import logging
 import os
 from typing import Dict, List, Optional
 import botocore
@@ -13,6 +15,8 @@ from amazon_sagemaker_jupyter_scheduler.app_metadata import (
 
 LOOSELEAF_STAGE_MAPPING = {"devo": "beta", "loadtest": "gamma"}
 
+from amazon_sagemaker_jupyter_scheduler.util.constants import IAM_TIMEOUT
+
 
 class BaseAsyncBotoClient:
     cfg: any
@@ -29,21 +33,7 @@ class BaseAsyncBotoClient:
         )
         self.partition = partition
         self.region_name = region_name
-
-        # aiobotocore is pinned to botocore 1.23 but our training changes are very recent.
-        # copied the latest model file from botocore https://github.com/boto/botocore/blob/develop/botocore/data/sagemaker/2017-07-24/service-2.json
-        # This env should cause botocore to load this model - https://botocore.amazonaws.com/v1/documentation/api/latest/reference/loaders.html
-        # and not affect any other clients running in the environment
-        PACKAGE_ROOT = os.path.abspath(os.path.dirname(__file__))
-        os.environ["SCHEDULING_DATA_PATH"] = os.path.join(
-            PACKAGE_ROOT, "botocore_model"
-        )
-        # we want to modify the default search path for service models
-        # https://github.com/boto/botocore/blob/develop/botocore/configprovider.py#L53
-        # TODO: Find a way to upgrade aiobotocore and remove this hack
-        self.sess = get_session(
-            {"data_path": ("data_path", "SCHEDULING_DATA_PATH", None, None)}
-        )
+        self.sess = get_session()
 
 
 class SageMakerAsyncBoto3Client(BaseAsyncBotoClient):
@@ -51,6 +41,11 @@ class SageMakerAsyncBoto3Client(BaseAsyncBotoClient):
         # based on the Studio domain stage, we want to choose the sagemaker endpoint
         # rest of the services will use prod stages for non prod stages
         stage = InternalMetadataAdapter().get_stage()
+        self.cfg = botocore.client.Config(
+            connect_timeout=3,
+            read_timeout=15,
+            retries={"max_attempts": 2},
+        )
         create_client_args = {
             "service_name": "sagemaker",
             "config": self.cfg,
@@ -152,6 +147,10 @@ class SageMakerAsyncBoto3Client(BaseAsyncBotoClient):
         async with self._create_sagemaker_client() as sm:
             return await sm.describe_space(DomainId=domain_id, SpaceName=space_name)
 
+    async def describe_app(self, domain_id: str, space_name: str, app_type: str, app_name: str) -> Dict:
+        async with self._create_sagemaker_client() as sm:
+            return await sm.describe_app(DomainId=domain_id, SpaceName=space_name, AppType=app_type, AppName=app_name)
+
     async def create_pipeline(
         self,
         pipeline_name: str,
@@ -214,6 +213,11 @@ class SageMakerAsyncBoto3Client(BaseAsyncBotoClient):
                 PipelineExecutionArn=pipeline_execution_arn
             )
 
+    async def describe_image(self, image_name: str) -> Dict:
+         async with self._create_sagemaker_client() as sm:
+            describe_image_version_args = {"ImageName": image_name}
+            return await sm.describe_image(**describe_image_version_args)
+
     async def describe_image_version(
         self, image_name: str, image_version_number: int = None
     ) -> Dict:
@@ -293,6 +297,20 @@ class S3AsyncBoto3Client:
         async with self._create_s3_client() as s3:
             response = await s3.get_object(Bucket=bucket, Key=key)
             return await response["Body"].read()
+        
+    async def list_objects(self, bucket: str, prefix: str) -> List[str]:
+        async with self._create_s3_client() as s3:
+            paginator = s3.get_paginator('list_objects_v2')
+            params = {'Bucket': bucket, 'Prefix': prefix}
+            page_iterator = paginator.paginate(**params)
+
+            list_s3_objects = []
+            async for page in page_iterator:
+                contents = page.get('Contents', [])
+                for content in contents:
+                    list_s3_objects.append(content.get("Key", ""))
+
+            return list_s3_objects
 
     async def create_bucket(self, bucket_name: str, region_name: str):
         async with self._create_s3_client() as s3:
@@ -309,6 +327,10 @@ class S3AsyncBoto3Client:
                     Bucket=bucket_name,
                     CreateBucketConfiguration={"LocationConstraint": region_name},
                 )
+            
+    async def head_bucket(self, bucket_name: str):
+        async with self._create_s3_client() as s3:
+            return await s3.head_bucket(Bucket=bucket_name)
 
     async def enable_server_side_encryption_with_s3_keys(self, bucket_name: str):
         async with self._create_s3_client() as s3:
@@ -457,10 +479,23 @@ def get_ec2_client():
 
 class STSAsyncBotoClient(BaseAsyncBotoClient):
     def _create_sts_client(self):
+        session = botocore.session.Session()
+        endpoint_resolver = session.get_component('endpoint_resolver')
+        endpoint_data = endpoint_resolver.construct_endpoint('sts', self.region_name)
+
+        # Use the resolved endpoint if available; otherwise, default to global STS endpoint
+        endpoint_url = "https://sts.amazonaws.com"  # default global endpoint
+        if endpoint_data and 'hostname' in endpoint_data:
+            resolved_url = endpoint_data['hostname']
+            if not resolved_url.startswith("https://"):
+                resolved_url = "https://" + resolved_url
+            endpoint_url = resolved_url
+
         return self.sess.create_client(
             "sts",
             config=self.cfg,
             region_name=self.region_name,
+            endpoint_url=endpoint_url
         )
 
     # Used to get AWS account id
@@ -502,6 +537,17 @@ class IAMAsyncBotoClient(BaseAsyncBotoClient):
                         matching_role_arns.append(role["Arn"])
         return matching_role_arns
 
+    async def list_role_arns_with_matching_prefix_timeout_wrapper(
+        self, prefix: str, logger
+    ) -> List[str]:
+        try:
+            return await asyncio.wait_for(
+                self.list_role_arns_with_matching_prefix(prefix), timeout=IAM_TIMEOUT
+            )
+        except asyncio.TimeoutError:
+            logger.info("IAM call timed out, returning empty response")
+            return []
+
 
 def get_iam_client():
     return IAMAsyncBotoClient(get_partition(), get_region_name())
