@@ -9,5 +9,7 @@ def get_revenue_attribution_string():
     revenue_string = "sagemaker_headless_execution_vanilla"
     if get_sagemaker_environment() == JupyterLabEnvironment.SAGEMAKER_STUDIO:
         revenue_string = "sagemaker_headless_execution"
+    elif get_sagemaker_environment() == JupyterLabEnvironment.SAGEMAKER_JUPYTERLAB:
+        revenue_string = "sagemaker_headless_execution_jupyterlab"
 
     return revenue_string
