@@ -1,6 +1,7 @@
 import os
 import asyncio
 import json
+from amazon_sagemaker_jupyter_scheduler.util.constants import DEFAULT_JOB_DEFINITION_RETRY_VALUE
 from aws_embedded_metrics.logger.metrics_context import MetricsContext
 
 import botocore
@@ -34,6 +35,7 @@ from amazon_sagemaker_jupyter_scheduler.logging import async_with_metrics
 from amazon_sagemaker_jupyter_scheduler.app_metadata import (
     get_partition,
     get_region_name,
+    get_space_type,
 )
 
 from amazon_sagemaker_jupyter_scheduler.clients import (
@@ -79,6 +81,7 @@ from amazon_sagemaker_jupyter_scheduler.runtime_environment_parameters import (
 
 EVENT_BRIDGE_RULE_TARGET_ID = "notebook-execution"
 SAGEMAKER_PIPELINE_STEP_NAME = "notebook-execution"
+SHARED_SPACE_PREFIX = "RTC:"
 
 
 class SageMakerScheduler(BaseScheduler):
@@ -131,44 +134,29 @@ class SageMakerScheduler(BaseScheduler):
     async def get_additional_tags(self) -> List[Dict]:
         return []
 
-    async def _get_system_dependencies_version(
-        self, stage_name: str, region_name: str
-    ) -> str:
-        # TODO: new region addition should have a way to read from a config if we get into bucket snpping
-        # TODO: handle errors like network, permission issues
-        s3_bucket_name = f"sagemakerheadlessexecution-{stage_name}-{region_name}"
-
-        try:
-            response_content = await self.s3_client().get_object_content(
-                bucket=s3_bucket_name, key="headless_system_dependencies/latest"
-            )
-        except botocore.exceptions.ClientError as error:
-            raise SageMakerSchedulerError.from_boto_error(
-                error,
-                f"Retrieving Notebook Execution driver from service s3 bucket - {s3_bucket_name} failed",
-            )
-        self.log.info("Successfully called S3 GetObject for system dependencies")
-        latest_file = json.loads(response_content)
-        self.log.info(f"S3 response for {s3_bucket_name} with {latest_file}")
-        return f"s3://{s3_bucket_name}/headless_system_dependencies/build_{latest_file['latest']}"
 
     def handle_aws_client_error(self, error, log_message=None):
         if isinstance(error, SchedulerError):
             raise error
         elif isinstance(error, botocore.exceptions.ClientError):
             if log_message is not None:
-                self.log.error(f"Boto client Error: {log_message}")
+                self.log.error(f"[SageMakerScheduler] Boto client Error: {log_message}")
             raise SageMakerSchedulerError.from_boto_error(error)
         elif isinstance(error, RuntimeError):
             if log_message is not None:
-                self.log.error(f"Runtime Error: {log_message}")
+                self.log.error(f"[SageMakerScheduler] Runtime Error: {log_message}")
             raise SageMakerSchedulerError.from_runtime_error(error)
         elif isinstance(error, FileNotFoundError):
-            self.log.error(f"File not found error: {str(error)}")
+            self.log.error(f"[SageMakerScheduler] File not found error: {str(error)}")
             raise SchedulerError(str(error))
         elif isinstance(error, botocore.exceptions.NoCredentialsError):
-            self.log.error(f"No Credentials Error: {log_message}")
+            self.log.error(f"[SageMakerScheduler] No Credentials Error: {log_message}")
             raise SageMakerSchedulerError.from_no_credentials_error(error)
+        elif isinstance(error, botocore.exceptions.ConnectionError):
+            # also filters child classes of ConnectionError - ReadTimeoutError, SSLError
+            # ConnectTimeoutError, EndpointConnectionError, ProxyConnectionError, ReadTimeoutError
+            self.log.error(f"[SageMakerScheduler] {error.__class__.__name__}: {log_message}")
+            raise SageMakerSchedulerError.from_connection_error(error)
         else:
             if log_message is None:
                 raise error
@@ -176,9 +164,11 @@ class SageMakerScheduler(BaseScheduler):
                 self.log.error(log_message)
                 raise self.error_factory.internal_error(error) from error
 
-    async def _verify_bucket_region_and_owner(self, bucket_name: str):
+    async def _verify_bucket_region_and_owner(self, bucket_name: str, cross_account_id: str = ''):
+        account_id = cross_account_id if cross_account_id else await get_aws_account_id()
+
         bucket_location = await self.s3_client().get_bucket_location(
-            bucket=bucket_name, accountId=await get_aws_account_id()
+            bucket=bucket_name, accountId=account_id
         )
 
         # LocationConstraint will be null when bucket is in us-east-1
@@ -192,38 +182,40 @@ class SageMakerScheduler(BaseScheduler):
         self,
         deletable_resources: DeletableResourceContainer,
         training_job_name: str,
-        s3_uri: str,
+        file_name: str,
         runtime_environment_parameters: RuntimeEnvironmentParameters,
         root_dir: str,
+        packaged_file_paths: List[str],
     ) -> S3FileUploader:
         input_uri = S3URI(runtime_environment_parameters.s3_input)
         output_uri = S3URI(runtime_environment_parameters.s3_output)
 
         try:
-            if input_uri.bucket == output_uri.bucket:
-                await self._verify_bucket_region_and_owner(input_uri.bucket)
-            else:
-                await asyncio.gather(
-                    self._verify_bucket_region_and_owner(input_uri.bucket),
-                    self._verify_bucket_region_and_owner(output_uri.bucket),
+            await asyncio.gather(
+                    self._verify_bucket_region_and_owner(input_uri.bucket, runtime_environment_parameters.s3_input_account_id),
+                    self._verify_bucket_region_and_owner(output_uri.bucket, runtime_environment_parameters.s3_output_account_id),
                 )
         except botocore.exceptions.ClientError as error:
             raise SageMakerSchedulerError.from_boto_error(
                 error,
-                f"GetBucketLocation failed for {set([input_uri.bucket, output_uri.bucket])}",
+                f"Failed to verify bucket location and owner for {set([input_uri.bucket, output_uri.bucket])}",
             )
 
+        file_upload_account_id = runtime_environment_parameters.s3_input_account_id
+
         s3_file_uploader = S3FileUploader(
             deletable_resources,
             runtime_environment_parameters.s3_input,
+            file_upload_account_id,
             training_job_name,
-            s3_uri,
+            file_name,
             runtime_environment_parameters.sm_init_script,
             runtime_environment_parameters.sm_lcc_init_script_arn,
             root_dir,
+            packaged_file_paths
         )
 
-        self.log.info(f"Uploading artifacts for job {training_job_name}...")
+        self.log.info(f"[SageMakerScheduler] Uploading artifacts for job {training_job_name}...")
         try:
             await s3_file_uploader.upload()
         except Exception as error:
@@ -231,10 +223,27 @@ class SageMakerScheduler(BaseScheduler):
                 error, f"Uploading artifacts to S3 bucket failed - {input_uri.bucket}"
             )
 
-        self.log.info(f"Successfully uploaded artifacts for job {training_job_name}.")
+        self.log.info(f"[SageMakerScheduler] Successfully uploaded artifacts for job {training_job_name}.")
 
         return s3_file_uploader
 
+    def get_packaged_file_paths(self, input_uri: str) -> List[str]:
+        packaged_file_paths = []
+        input_notebook_path = os.path.join(self.root_dir, input_uri)
+        source_dir = os.path.dirname(input_notebook_path)
+
+        for dirpath, dirs, files in os.walk(source_dir):
+            dirs[:] = [dir for dir in dirs if not dir.startswith(".")]
+            files = [file for file in files if not file.startswith(".")]
+
+            for file in files:
+                filepath = os.path.join(dirpath, file)
+                if filepath != input_notebook_path:
+                    rel_path = os.path.relpath(filepath, source_dir)
+                    packaged_file_paths.append(rel_path)
+
+        return packaged_file_paths
+
     @async_with_metrics("CreateJob")
     async def create_job(self, input: CreateJob, metrics: MetricsContext) -> str:
         """
@@ -244,7 +253,11 @@ class SageMakerScheduler(BaseScheduler):
         """
 
         # log the input parameters
-        self.log.info(f"Input parameters for create_job: {input}")
+        self.log.info(f"[SageMakerScheduler] Input parameters for create_job: {input}")
+
+        if get_space_type() == "shared":
+            input.input_uri = input.input_uri.replace(SHARED_SPACE_PREFIX, "", 1)
+            self.log.info(f'Shared Space: remove the RTC: prefix {input.input_uri}')
 
         training_job_name = generate_job_identifier(
             name=input.name,
@@ -254,37 +267,38 @@ class SageMakerScheduler(BaseScheduler):
 
         deletable_resources = DeletableResourceContainer(self.log)
 
+        packaged_file_paths = []
+        if input.package_input_folder:
+            packaged_file_paths = self.get_packaged_file_paths(input.input_uri)
+            self.log.info("[SageMakerScheduler] Creating a job with packaged input folder...")
         try:
             s3_file_uploader = await self._prepare_job_artifacts(
                 deletable_resources=deletable_resources,
                 training_job_name=training_job_name,
-                s3_uri=input.input_uri,
+                file_name=input.input_uri,
                 runtime_environment_parameters=RuntimeEnvironmentParameters(
                     input.runtime_environment_parameters
                 ),
                 root_dir=self.root_dir,
+                packaged_file_paths=packaged_file_paths
             )
 
-            self.log.info(f"Getting S3 dependency Uri...")
+            self.log.info(f"[SageMakerScheduler] Getting S3 dependency Uri...")
             stage = InternalMetadataAdapter().get_stage()
-            s3_dependency_uri = await self._get_system_dependencies_version(
-                stage, get_region_name()
-            )
-            self.log.info(f"Successfully got S3 dependency Uri")
+            self.log.info(f"[SageMakerScheduler] Successfully got S3 dependency Uri")
 
             create_training_job_input = (
                 await self.converter.to_create_training_job_input(
                     training_job_name=training_job_name,
                     upstream_model=input,
                     s3_file_uploader=s3_file_uploader,
-                    s3_dependency_uri=s3_dependency_uri,
                 )
             )
 
             create_training_job_input["TrainingJobName"] = training_job_name
 
             self.log.info(
-                f"Calling SageMaker CreateTrainingJob for job {training_job_name}..."
+                f"[SageMakerScheduler] Calling SageMaker CreateTrainingJob for job {training_job_name}..."
             )
 
             try:
@@ -303,7 +317,7 @@ class SageMakerScheduler(BaseScheduler):
                 )
             except Exception as error:
                 self.log.error(
-                    f"Error when calling SageMaker CreateTrainingJob or ListTags with job {training_job_name}: {error}"
+                    f"[SageMakerScheduler] Error when calling SageMaker CreateTrainingJob or ListTags with job {training_job_name}: {error}"
                 )
                 raise error
 
@@ -316,7 +330,7 @@ class SageMakerScheduler(BaseScheduler):
             await deletable_resources.delete_all()
 
         self.log.info(
-            f"Successfully called SageMaker CreateTrainingJob for job {training_job_name}."
+            f"[SageMakerScheduler] Successfully called SageMaker CreateTrainingJob for job {training_job_name}."
         )
 
         return training_job_name
@@ -331,13 +345,13 @@ class SageMakerScheduler(BaseScheduler):
         try:
             metrics.set_property("Id", job_definition_id)
             self.log.info(
-                f"Calling SageMaker DescribePipeline for pipeline {job_definition_id}..."
+                f"[SageMakerScheduler] Calling SageMaker DescribePipeline for pipeline {job_definition_id}..."
             )
             describe_pipeline_response = (
                 await self.sagemaker_client().describe_pipeline(job_definition_id)
             )
             self.log.info(
-                f"Successfully called SageMaker DescribePipeline for pipeline {job_definition_id}."
+                f"[SageMakerScheduler] Successfully called SageMaker DescribePipeline for pipeline {job_definition_id}."
             )
 
             training_job_details = json.loads(
@@ -347,7 +361,7 @@ class SageMakerScheduler(BaseScheduler):
             environment = training_job_details["Environment"]
 
             tag_dict = self.converter.to_tag_dict(training_job_details["Tags"])
-            job_name = tag_dict[JobTag.NOTEBOOK_NAME.value]
+            job_name = tag_dict[JobTag.NAME.value]
             notebook_name = environment[
                 JobEnvironmentVariableName.SM_INPUT_NOTEBOOK_NAME.value
             ]
@@ -368,10 +382,10 @@ class SageMakerScheduler(BaseScheduler):
             training_job_details["TrainingJobName"] = job_id
             training_job_details["HyperParameters"] = model.parameters or {}
 
-            self.log.info(f"Calling SageMaker CreateTrainingJob for job {job_id}...")
+            self.log.info(f"[SageMakerScheduler] Calling SageMaker CreateTrainingJob for job {job_id}...")
             await self.sagemaker_client().create_training_job(training_job_details)
             self.log.info(
-                f"Successfully called SageMaker CreateTrainingJob for job {job_id}."
+                f"[SageMakerScheduler] Successfully called SageMaker CreateTrainingJob for job {job_id}."
             )
             return job_id
         except Exception as error:
@@ -390,7 +404,13 @@ class SageMakerScheduler(BaseScheduler):
     ) -> ListJobsResponse:
         """Returns list of all jobs filtered by query"""
 
-        self.log.info("Calling SageMaker Search...")
+        self.log.info("[SageMakerScheduler] Calling SageMaker Search...")
+
+        # max_items has default value and if it's overridden as 0, return empty list without calling
+        # search API. Max_items as 0 is used by a contract from OSS side to detect the
+        # scheduler extension availability.
+        if query.max_items == 0:
+            return ListJobsResponse(jobs=[])
 
         try:
             training_job_list_response = await self.sagemaker_client().search(
@@ -401,7 +421,7 @@ class SageMakerScheduler(BaseScheduler):
                 error, f"Error when calling SageMaker Search: {error}"
             )
 
-        self.log.info("Successfully called SageMaker Search.")
+        self.log.info("[SageMakerScheduler] Successfully called SageMaker Search.")
 
         return self.converter.to_jupyter_list_jobs_response(
             self, training_job_list_response
@@ -420,7 +440,7 @@ class SageMakerScheduler(BaseScheduler):
     ) -> DescribeJob:
         """Returns job record for a single job"""
 
-        self.log.info(f"Calling SageMaker DescribeTrainingJob for job {job_id}...")
+        self.log.info(f"[SageMakerScheduler] Calling SageMaker DescribeTrainingJob for job {job_id}...")
 
         try:
             training_job_response = await self.sagemaker_client().describe_training_job(
@@ -433,13 +453,13 @@ class SageMakerScheduler(BaseScheduler):
             )
 
         self.log.info(
-            f"Successfully called SageMaker DescribeTrainingJob for job {job_id}."
+            f"[SageMakerScheduler] Successfully called SageMaker DescribeTrainingJob for job {job_id}."
         )
 
         # Extract the Training Job ARN from the response since its case might differ from the Training Job Name.
         resource_arn = training_job_response["TrainingJobArn"]
 
-        self.log.info(f"Calling SageMaker ListTags for {resource_arn}...")
+        self.log.info(f"[SageMakerScheduler] Calling SageMaker ListTags for {resource_arn}...")
 
         try:
             list_tags_response = await self.sagemaker_client().list_tags(
@@ -451,7 +471,7 @@ class SageMakerScheduler(BaseScheduler):
                 f"Error when calling SageMaker ListTags for {resource_arn}: {error}",
             )
 
-        self.log.info(f"Successfully called SageMaker ListTags for {resource_arn}.")
+        self.log.info(f"[SageMakerScheduler] Successfully called SageMaker ListTags for {resource_arn}.")
 
         return self.converter.to_jupyter_describe_job_output(
             scheduler=self,
@@ -468,11 +488,19 @@ class SageMakerScheduler(BaseScheduler):
 
         # Call DescribeTrainingJob to get the ARN, since its case does not necessarily not match the training job name.
         self.log.info(f"Calling SageMaker DescribeTrainingJob for job {job_id}...")
-        training_job_details = await self.sagemaker_client().describe_training_job(
-            job_id
-        )
+
+        try:
+            training_job_details = await self.sagemaker_client().describe_training_job(
+                job_id
+            )
+        except Exception as error:
+            self.handle_aws_client_error(
+                error,
+                f"Error in describe_training_job while processing job {job_id}"
+            )
+
         self.log.info(
-            f"Successfully called SageMaker DescribeTrainingJob for job {job_id}..."
+            f"[SageMakerScheduler] Successfully called SageMaker DescribeTrainingJob for job {job_id}..."
         )
 
         resource_arn = training_job_details["TrainingJobArn"]
@@ -496,32 +524,32 @@ class SageMakerScheduler(BaseScheduler):
                 stop_job_response
             ):
                 self.log.error(
-                    f"Boto client error when calling SageMaker StopTrainingJob for job {job_id}: {stop_job_response}"
+                    f"[SageMakerScheduler] Boto client error when calling SageMaker StopTrainingJob for job {job_id}: {stop_job_response}"
                 )
                 raise self.error_converter.boto_error_to_web_error(
                     stop_job_response
                 ) from stop_job_response
         elif isinstance(stop_job_response, Exception):
             self.log.error(
-                f"Error when calling SageMaker StopTrainingJob for job {job_id}: {stop_job_response}"
+                f"[SageMakerScheduler] Error when calling SageMaker StopTrainingJob for job {job_id}: {stop_job_response}"
             )
             raise self.error_factory.internal_error(
                 stop_job_response
             ) from stop_job_response
 
         self.log.info(
-            f"Successfully called SageMaker StopTrainingJob for job {job_id}."
+            f"[SageMakerScheduler] Successfully called SageMaker StopTrainingJob for job {job_id}."
         )
 
         if isinstance(add_tag_response, Exception):
             self.log.error(
-                f"Error when calling SageMaker AddTags for {resource_arn}: {add_tag_response}"
+                f"[SageMakerScheduler] Error when calling SageMaker AddTags for {resource_arn}: {add_tag_response}"
             )
             raise self.error_factory.internal_error(
                 add_tag_response
             ) from add_tag_response
 
-        self.log.info(f"Successfully called SageMaker ListTags for {resource_arn}.")
+        self.log.info(f"[SageMakerScheduler] Successfully called SageMaker ListTags for {resource_arn}.")
 
     @async_with_metrics("StopJob")
     async def stop_job(self, job_id: str, metrics: MetricsContext):
@@ -537,7 +565,7 @@ class SageMakerScheduler(BaseScheduler):
         """
 
         metrics.set_property("Id", job_id)
-        self.log.info(f"Calling SageMaker StopTrainingJob for job {job_id}...")
+        self.log.info(f"[SageMakerScheduler] Calling SageMaker StopTrainingJob for job {job_id}...")
 
         try:
             await self.sagemaker_client().stop_training_job(job_id)
@@ -548,7 +576,7 @@ class SageMakerScheduler(BaseScheduler):
             )
 
         self.log.info(
-            f"Successfully called SageMaker StopTrainingJob for job {job_id}."
+            f"[SageMakerScheduler] Successfully called SageMaker StopTrainingJob for job {job_id}."
         )
 
     def get_created_resources_description_text(self):
@@ -568,6 +596,10 @@ class SageMakerScheduler(BaseScheduler):
 
         schedule_expression = f"cron({cron_expression})"
 
+        if get_space_type() == "shared":
+            model.input_uri = model.input_uri.replace(SHARED_SPACE_PREFIX, "", 1)
+            self.log.info(f'[SageMakerScheduler] Job Definition: Shared Space: remove the RTC: prefix {model.input_uri}')
+
         # 1. S3 -- Prepare the training job artifacts.
         job_definition_id = generate_job_identifier(
             name=model.name,
@@ -582,30 +614,31 @@ class SageMakerScheduler(BaseScheduler):
 
         deletable_resources = DeletableResourceContainer(self.log)
 
+        packaged_file_paths = []
+        if model.package_input_folder: 
+            packaged_file_paths = self.get_packaged_file_paths(model.input_uri)
+
         try:
             s3_file_uploader = await self._prepare_job_artifacts(
                 deletable_resources=deletable_resources,
                 training_job_name=job_definition_id,
-                s3_uri=model.input_uri,
+                file_name=model.input_uri,
                 runtime_environment_parameters=runtime_environment_parameters,
                 root_dir=self.root_dir,
+                packaged_file_paths=packaged_file_paths
             )
 
             # 2. SageMaker:CreatePipeline
             self.log.info(
-                f"Calling SageMaker CreatePipeline for job definition {job_definition_id}"
+                f"[SageMakerScheduler] Calling SageMaker CreatePipeline for job definition {job_definition_id}"
             )
 
             stage = InternalMetadataAdapter().get_stage()
-            s3_dependency_uri = await self._get_system_dependencies_version(
-                stage, get_region_name()
-            )
             create_training_job_input = (
                 await self.converter.to_create_training_job_input(
                     training_job_name=job_definition_id,
                     upstream_model=model,
                     s3_file_uploader=s3_file_uploader,
-                    s3_dependency_uri=s3_dependency_uri,
                 )
             )
             create_training_job_input["RetryStrategy"]["MaximumRetryAttempts"] = 1
@@ -624,7 +657,7 @@ class SageMakerScheduler(BaseScheduler):
                 create_training_job_input["Tags"] = [] + common_tags
 
                 # log the create_training_job_input
-                self.log.info(f"create_training_job_input: {create_training_job_input}")
+                self.log.info(f"[SageMakerScheduler] create_training_job_input: {create_training_job_input}")
 
                 create_training_job_input["Tags"].append(
                     {
@@ -642,7 +675,8 @@ class SageMakerScheduler(BaseScheduler):
                 ] = get_pipeline_expression_output_name(
                     model.name, notebook_name_without_ext, notebook_extension
                 )
-                maxAttempts = runtime_environment_parameters.max_retry_attempts if hasattr(runtime_environment_parameters, "max_retry_attempts") else 1
+
+                maxAttempts = runtime_environment_parameters.max_retry_attempts if hasattr(runtime_environment_parameters, "max_retry_attempts") else DEFAULT_JOB_DEFINITION_RETRY_VALUE
                 maxAttempts = int(maxAttempts)
                 pipeline_result = await self.sagemaker_client().create_pipeline(
                     pipeline_name=job_definition_id,
@@ -678,7 +712,7 @@ class SageMakerScheduler(BaseScheduler):
                 )
             except Exception as error:
                 self.log.error(
-                    f"Error when calling SageMaker CreatePipeline for job definition {job_definition_id}: {error}"
+                    f"[SageMakerScheduler] Error when calling SageMaker CreatePipeline for job definition {job_definition_id}: {error}"
                 )
                 raise error
 
@@ -691,11 +725,11 @@ class SageMakerScheduler(BaseScheduler):
             )
 
             self.log.info(
-                f"Successfully called SageMaker CreatePipeline: {pipeline_arn}."
+                f"[SageMakerScheduler] Successfully called SageMaker CreatePipeline: {pipeline_arn}."
             )
 
             # 3. EventBridge:PutRule
-            self.log.info(f"Calling EventBridge PutRule for pipeline {pipeline_arn}...")
+            self.log.info(f"[SageMakerScheduler] Calling EventBridge PutRule for pipeline {pipeline_arn}...")
 
             try:
                 put_rule_result = await self.event_bridge_client().put_rule(
@@ -707,7 +741,7 @@ class SageMakerScheduler(BaseScheduler):
                 )
             except Exception as error:
                 self.log.error(
-                    f"Error when calling EventBridge PutRule for job definition {job_definition_id}: {error}"
+                    f"[SageMakerScheduler] Error when calling EventBridge PutRule for job definition {job_definition_id}: {error}"
                 )
                 raise error
 
@@ -719,10 +753,10 @@ class SageMakerScheduler(BaseScheduler):
                 )
             )
 
-            self.log.info(f"Successfully called EventBridge PutRule: {rule_arn}")
+            self.log.info(f"[SageMakerScheduler] Successfully called EventBridge PutRule: {rule_arn}")
 
             # 4. EventBridge:PutTargets
-            self.log.info(f"Calling EventBridge PutTargets for rule {rule_arn}...")
+            self.log.info(f"[SageMakerScheduler] Calling EventBridge PutTargets for rule {rule_arn}...")
 
             try:
                 await self.event_bridge_client().put_targets(
@@ -737,7 +771,7 @@ class SageMakerScheduler(BaseScheduler):
                 )
             except Exception as error:
                 self.log.error(
-                    f"Error when calling EventBridge PutTargets for rule {rule_arn}: {error}"
+                    f"[SageMakerScheduler] Error when calling EventBridge PutTargets for rule {rule_arn}: {error}"
                 )
                 raise error
 
@@ -749,7 +783,7 @@ class SageMakerScheduler(BaseScheduler):
         finally:
             await deletable_resources.delete_all()
 
-        self.log.info(f"Successfully called EventBridge PutTargets for rule {rule_arn}")
+        self.log.info(f"[SageMakerScheduler] Successfully called EventBridge PutTargets for rule {rule_arn}")
 
         return job_definition_id
 
@@ -759,7 +793,7 @@ class SageMakerScheduler(BaseScheduler):
         cron_expression = EventBridgeCronExpressionAdapter(model.schedule).cron_expression
         schedule_expression = f"cron({cron_expression})"
 
-        self.log.info(f"Calling EventBridge PutRule for rule {job_definition_id}...")
+        self.log.info(f"[SageMakerScheduler] Calling EventBridge PutRule for rule {job_definition_id}...")
 
         try:
             await self.event_bridge_client().put_rule(
@@ -775,7 +809,7 @@ class SageMakerScheduler(BaseScheduler):
             )
 
         self.log.info(
-            f"Successfully called EventBridge PutRule for rule {job_definition_id}"
+            f"[SageMakerScheduler] Successfully called EventBridge PutRule for rule {job_definition_id}"
         )
 
     @async_with_metrics("UpdateJobDefinition")
@@ -853,7 +887,7 @@ class SageMakerScheduler(BaseScheduler):
         metrics: MetricsContext = None,
     ) -> DescribeJobDefinition:
         """Returns job definition record for a single job definition"""
-        self.log.info(f"Calling Sagemaker Describe Pipeline for {job_definition_id}...")
+        self.log.info(f"[SageMakerScheduler] Calling Sagemaker Describe Pipeline for {job_definition_id}...")
         # We will invoke one api call to get all associated tags for a given job_definition,
         # as tags will be stored in both SM Pipeline and Eventbridge rule
         try:
@@ -869,18 +903,18 @@ class SageMakerScheduler(BaseScheduler):
             )
 
         self.log.info(
-            f"Successfully called SageMaker Describe Pipeline for {job_definition_id}."
+            f"[SageMakerScheduler] Successfully called SageMaker Describe Pipeline for {job_definition_id}."
         )
 
         if not list_tags_response:
             self.log.info(
-                f"Calling SageMaker ListTags for pipeline {job_definition_id}..."
+                f"[SageMakerScheduler] Calling SageMaker ListTags for pipeline {job_definition_id}..."
             )
             list_tags_response = await self.sagemaker_client().list_tags(
                 resource_arn=describe_pipeline["PipelineArn"]
             )
             self.log.info(
-                f"Successfully called SageMaker ListTags for pipeline {job_definition_id}."
+                f"[SageMakerScheduler] Successfully called SageMaker ListTags for pipeline {job_definition_id}."
             )
 
         return self.converter.to_jupyter_describe_job_definition_output(
@@ -896,7 +930,7 @@ class SageMakerScheduler(BaseScheduler):
     ) -> ListJobDefinitionsResponse:
         """Returns list of all job definitions filtered by query"""
 
-        self.log.info("Calling SageMaker Search...")
+        self.log.info("[SageMakerScheduler] Calling SageMaker Search...")
 
         try:
             pipeline_list_response = await self.sagemaker_client().search(
@@ -905,7 +939,7 @@ class SageMakerScheduler(BaseScheduler):
         except Exception as error:
             self.handle_aws_client_error(
                 error,
-                self.log.error(f"Error when calling list_job_definitions : {error}"),
+                self.log.error(f"[SageMakerScheduler] Error when calling list_job_definitions : {error}"),
             )
 
         pipeline_results = pipeline_list_response["Results"]
@@ -935,7 +969,7 @@ class SageMakerScheduler(BaseScheduler):
             else:
                 pipeline = pipeline_results[idx]["Pipeline"]
                 self.log.error(
-                    f"Error when getting job definition for {pipeline['PipelineArn']} : {describe_job_definition}"
+                    f"[SageMakerScheduler] Error when getting job definition for {pipeline['PipelineArn']} : {describe_job_definition}"
                 )
 
         return ListJobDefinitionsResponse(
@@ -968,7 +1002,8 @@ class SageMakerScheduler(BaseScheduler):
         {
             'ipynb': '/job_files/helloworld-2022-10-10.ipynb',
             'html': '/job_files/helloworld-2022-10-10.html',
-            'input': '/job_files/helloworld.ipynb'
+            'input': '/job_files/helloworld.ipynb',
+            'files': ["abc.txt", "def.csv"]
         }
 
         For files that are archived as tar or compressed tar
@@ -977,7 +1012,8 @@ class SageMakerScheduler(BaseScheduler):
             'tar.gz': '/job_files/helloworld.tar.gz',
             'ipynb': 'helloworld-2022-10-10.ipynb',
             'html': 'helloworld-2022-10-10.html',
-            'input': 'helloworld.ipynb'
+            'input': 'helloworld.ipynb',
+            'files': ["abc.txt", "def.csv"]
         }
 
         Parameters
@@ -1008,6 +1044,10 @@ class SageMakerScheduler(BaseScheduler):
         #   To: hello-7-Hello-2022-10-24T18-59-43-851Z.ipynb
         output_filename_parts = os.path.splitext(original_output_file_name)
 
+        files = []
+        if model.package_input_folder and model.packaged_files:
+            files = model.packaged_files
+
         # Define all known output formats, then remove unavailable ones depending on the job status.
         output_mapping = {
             "tar.gz": os.path.join(
@@ -1024,6 +1064,7 @@ class SageMakerScheduler(BaseScheduler):
                 + output_filename_parts[1]
             ),
             "log": "sagemaker_job_execution.log",
+            "files": files
         }
 
         if model.status == Status.COMPLETED:
