@@ -1,3 +1,4 @@
+import asyncio
 import os
 import pytest
 from unittest.mock import MagicMock, patch, mock_open
@@ -39,7 +40,7 @@ TEST_SUBNETS_IDS_ATTACHED_TO_DOMAIN = [
     "subnet-05305f168f2ef2ac7",
 ]
 PUBLIC_SUBNETS = ["subnet-07fc038adc7621412", "subnet-0a959d457c3d0ed01"]
-
+SUBNET_NOT_SHARED_WITH_ACCOUNT = "subnet-0f582c59423f35419f"
 MOCK_RESOURCE_METADATA = """
 {
   "ResourceArn": "arn:aws:sagemaker:us-west-2:112233445566:app/d-1a2b3c4d5e6f/fake-user/JupyterServer/default",
@@ -86,6 +87,13 @@ MOCK_DESCRIBE_ROUTE_TABLES_RESPONSE = {
                     "RouteTableId": "rtb-0802b33f7aa6bed8b",
                     "SubnetId": "subnet-0f582c5947f35419f",
                     "AssociationState": {"State": "associated"},
+                },
+                {
+                    "Main": False,
+                    "RouteTableAssociationId": "rtbassoc-04635e2ca02390347e",
+                    "RouteTableId": "rtb-0802b33f7aa6bed8b",
+                    "SubnetId": SUBNET_NOT_SHARED_WITH_ACCOUNT,
+                    "AssociationState": {"State": "associated"},
                 }
             ],
             "PropagatingVgws": [],
@@ -388,6 +396,129 @@ class TestAdvancedEnvironments:
             if env.name == "role_arn":
                 assert env.value == []
 
+    @pytest.mark.asyncio
+    async def test_auto_detect_domain_role_arn_when_iam_timeout(
+        self,
+        mock_list_role_arns_with_matching_prefix,
+        mock_get_caller_identity,
+        mock_get_partition_for_region,
+        mock_get_scoped_config,
+        mock_describe_routetables,
+        mock_describe_subnets,
+        mock_open,
+        mock_versioning,
+        mock_encryption,
+        mock_create_bucket,
+    ):
+        mock_describe_routetables.return_value = MOCK_DESCRIBE_ROUTE_TABLES_RESPONSE
+        mock_describe_subnets.return_value = MOCK_DESCRIBE_SUBNET_RESPONSE
+        mock_create_bucket.return_value = {
+            "Location": "/aws-emr-resources-177118115371-us-east-1"
+        }
+        mock_get_scoped_config.return_value.get.return_value = MOCK_REGION
+        mock_get_partition_for_region.return_value = MOCK_PARTITION
+        mock_get_caller_identity.return_value = MOCK_CALLER_IDENTITY
+
+        with patch.object(
+            IAMAsyncBotoClient,
+            "list_role_arns_with_matching_prefix",
+            side_effect=asyncio.TimeoutError(),
+        ):
+            response = await SageMakerAdvancedEnvironments().get_advanced_environments(
+                mock_logger
+            )
+            for env in response.auto_detected_config:
+                if env.name == "role_arn":
+                    assert env.value == []
+
+def test_lcc_arn_with_duplicates_happy_path():
+    expected_lcc_arns = []
+    MOCK_DOMAIN_DEFAULT_USER_SETTINGS = {
+        "ExecutionRole": "arn:aws:iam::708448604839:role/service-role/AmazonSageMakerServiceCatalogProductsExecutionRole",
+        "SharingSettings": {
+            "NotebookOutputOption": "Allowed",
+            "S3OutputPath": "s3://sagemaker-studio-708448604839-nl3i6t7eec/sharing",
+        },
+        "JupyterServerAppSettings": {
+            "DefaultResourceSpec": {
+                "SageMakerImageArn": "arn:aws:sagemaker:us-east-2:429704687514:image/jupyter-server-3",
+                "InstanceType": "system",
+            },
+            "LifecycleConfigArns": [
+                "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-echo"
+            ],
+        },
+        "KernelGatewayAppSettings": {
+            "LifecycleConfigArns": [
+                "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-kgw-echo"
+            ]
+        },
+        "CanvasAppSettings": {
+            "TimeSeriesForecastingSettings": {
+                "Status": "ENABLED",
+                "AmazonForecastRoleArn": "arn:aws:iam::708448604839:role/service-role/AmazonSagemakerCanvasForecastRole-tina",
+            }
+        },
+    }
+
+    MOCK_USER_SETTINGS = {
+        "ExecutionRole": "arn:aws:iam::708448604839:role/FinanceTeamRole",
+        "JupyterServerAppSettings": {
+            "DefaultResourceSpec": {
+                "SageMakerImageArn": "arn:aws:sagemaker:us-east-2:429704687514:image/jupyter-server-3",
+                "InstanceType": "system",
+            },
+            "LifecycleConfigArns": [
+                "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-echo"
+            ],
+        },
+        "KernelGatewayAppSettings": {
+            "LifecycleConfigArns": [
+                "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-user-kgw-echo"
+            ]
+        },
+        "CanvasAppSettings": {"TimeSeriesForecastingSettings": {"Status": "DISABLED"}},
+    }
+
+    MOCK_SPACE_SETTINGS = {
+        "ExecutionRole": "arn:aws:iam::123456789012:role/SomeSpaceRole",
+        "JupyterServerAppSettings": {
+            "DefaultResourceSpec": {
+                "SageMakerImageArn": "arn:aws:sagemaker:us-east-1:123456789012:image/jupyter-server-1",
+                "InstanceType": "ml.t3.medium",
+            },
+            "LifecycleConfigArns": [
+                "arn:aws:sagemaker:us-east-1:123456789012:studio-lifecycle-config/space-lifecycle-1"
+            ],
+        },
+        "KernelGatewayAppSettings": {
+            "LifecycleConfigArns": [
+                "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-user-kgw-echo"
+            ]
+        },
+        "CanvasAppSettings": {
+            "SomeCanvasSetting": {
+                "Status": "ENABLED",
+            }
+        },
+    }
+
+    env = SageMakerStudioAdvancedEnvironments()
+
+    expected_lcc_arns = [
+        "arn:aws:sagemaker:us-east-1:123456789012:studio-lifecycle-config/space-lifecycle-1",
+        "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-user-kgw-echo",
+        "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-echo",
+        "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-kgw-echo",
+    ]
+    actual_lcc_arns = env._get_lcc_arns(
+        MOCK_DOMAIN_DEFAULT_USER_SETTINGS, MOCK_USER_SETTINGS, MOCK_SPACE_SETTINGS
+    )
+
+    # Convert both lists to sets to make the assertion agnostic to order
+    assert len(expected_lcc_arns) == len(actual_lcc_arns)
+    assert set(expected_lcc_arns) == set(actual_lcc_arns)
+    
 
 def test_lcc_arn_happy_path():
     expected_lcc_arns = []
@@ -438,15 +569,59 @@ def test_lcc_arn_happy_path():
         "CanvasAppSettings": {"TimeSeriesForecastingSettings": {"Status": "DISABLED"}},
     }
 
+    # unit test is failing due to  space settings being missing.
+    #TODO: Update space settings mock for savitur
+    MOCK_SPACE_SETTINGS = {
+        "ExecutionRole": "arn:aws:iam::123456789012:role/SomeSpaceRole",
+        "JupyterServerAppSettings": {
+            "DefaultResourceSpec": {
+                "SageMakerImageArn": "arn:aws:sagemaker:us-east-1:123456789012:image/jupyter-server-1",
+                "InstanceType": "ml.t3.medium",
+            },
+            "LifecycleConfigArns": [
+                "arn:aws:sagemaker:us-east-1:123456789012:studio-lifecycle-config/space-lifecycle-1"
+            ],
+        },
+        "KernelGatewayAppSettings": {
+            "LifecycleConfigArns": [
+                "arn:aws:sagemaker:us-east-1:123456789012:studio-lifecycle-config/space-lifecycle-2"
+            ]
+        },
+        "CanvasAppSettings": {
+            "SomeCanvasSetting": {
+                "Status": "ENABLED",
+            }
+        },
+    }
+
     env = SageMakerStudioAdvancedEnvironments()
 
     expected_lcc_arns = [
+        "arn:aws:sagemaker:us-east-1:123456789012:studio-lifecycle-config/space-lifecycle-1",
+        "arn:aws:sagemaker:us-east-1:123456789012:studio-lifecycle-config/space-lifecycle-2",
         "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-user-echo",
         "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-user-kgw-echo",
         "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-echo",
         "arn:aws:sagemaker:us-east-2:708448604839:studio-lifecycle-config/test-kgw-echo",
     ]
     actual_lcc_arns = env._get_lcc_arns(
-        MOCK_DOMAIN_DEFAULT_USER_SETTINGS, MOCK_USER_SETTINGS
+        MOCK_DOMAIN_DEFAULT_USER_SETTINGS, MOCK_USER_SETTINGS, MOCK_SPACE_SETTINGS
     )
-    assert expected_lcc_arns == actual_lcc_arns
+
+    assert len(expected_lcc_arns) == len(actual_lcc_arns)
+    assert set(expected_lcc_arns) == set(actual_lcc_arns)
+
+@patch.object(EC2AsyncBotoClient, "list_subnets_by_vpc_id")
+@patch.object(EC2AsyncBotoClient, "list_routetable_by_vpc_id")
+@pytest.mark.asyncio
+async def test_ignoring_shared_vpc_subnet_from_other_aws_accounts(mock_describe_routetables, mock_describe_subnets):
+    # based on the ticket -
+    mock_describe_routetables.return_value = MOCK_DESCRIBE_ROUTE_TABLES_RESPONSE
+    mock_describe_subnets.return_value = MOCK_DESCRIBE_SUBNET_RESPONSE
+    env = SageMakerStudioAdvancedEnvironments()
+    response = await env._get_compatible_subnets("vpc-05ce35bb227e86484")
+
+    # subnets with igw and subnets that are not present in ec2 describe subnet response are ignored
+    for subnet in response:
+        assert subnet["name"] != SUBNET_NOT_SHARED_WITH_ACCOUNT
+
