@@ -9,7 +9,6 @@ from amazon_sagemaker_jupyter_scheduler.environment_detector import (
 )
 from amazon_sagemaker_jupyter_scheduler.environments import (
     SagemakerEnvironmentManager,
-    region_name_to_code,
 )
 
 
@@ -33,11 +32,3 @@ class TestSagemakerEnvironments:
         assert envs_response[0].name == "sagemaker-default-env"
         for instance in envs_response[0].compute_types:
             assert instance.startswith("ml")
-
-    def test_region_mapping(self):
-        package_root = os.path.abspath(os.path.dirname(__file__).rstrip("/tests"))
-        region_mapping_filename = os.path.join(package_root, "host_region_mapping.json")
-        with open(region_mapping_filename) as file:
-            region_mapping = json.load(file)["regions"]
-            for region_display_name in region_name_to_code.values():
-                assert region_display_name in region_mapping
