@@ -57,6 +57,7 @@ from amazon_sagemaker_jupyter_scheduler.scheduler import (
     SageMakerScheduler,
     EVENT_BRIDGE_RULE_TARGET_ID,
 )
+from amazon_sagemaker_jupyter_scheduler.tests.test_logging import MOCK_NETWORK_ACCESS_TYPE
 
 
 @pytest.fixture(autouse=True)
@@ -85,7 +86,7 @@ def create_scheduler_with_mocked_dependencies():
         error_matcher=Mock(),
         error_converter=Mock(),
         error_factory=Mock(),
-        log=logging.getLogger("test_logger"),
+        log = Mock(),
     )
 
 
@@ -412,45 +413,6 @@ async def test_list_job_definition_happy_path(mock_open):
     )
 
 
-@pytest.mark.asyncio
-@patch("builtins.open", new_callable=mock_open, read_data=MOCK_RESOURCE_METADATA)
-async def test_get_system_dependencies_version(mock_open):
-    scheduler = create_scheduler_with_mocked_dependencies()
-    body_json = {"latest": 123456789}
-    body_encoded = json.dumps(body_json).encode("utf-8")
-
-    scheduler._s3_client.get_object_content.return_value = future_with_result(
-        body_encoded
-    )
-
-    s3_uri = await scheduler._get_system_dependencies_version(
-        stage_name="devo", region_name="us-west-2"
-    )
-
-    assert (
-        s3_uri
-        == "s3://sagemakerheadlessexecution-devo-us-west-2/headless_system_dependencies/build_123456789"
-    )
-
-    s3_uri = await scheduler._get_system_dependencies_version(
-        stage_name="devo", region_name="us-west-2"
-    )
-
-    assert (
-        s3_uri
-        == "s3://sagemakerheadlessexecution-devo-us-west-2/headless_system_dependencies/build_123456789"
-    )
-
-    s3_uri = await scheduler._get_system_dependencies_version(
-        stage_name="loadtest", region_name="us-west-2"
-    )
-
-    assert (
-        s3_uri
-        == "s3://sagemakerheadlessexecution-loadtest-us-west-2/headless_system_dependencies/build_123456789"
-    )
-
-
 @pytest.mark.asyncio
 @patch("builtins.open", new_callable=mock_open, read_data=MOCK_RESOURCE_METADATA)
 async def test_get_staging_paths__job_completed__allows_downloading_all_outputs(
@@ -481,6 +443,8 @@ async def test_get_staging_paths__job_completed__allows_downloading_all_outputs(
             url="",
             create_time=123,
             update_time=456,
+            package_input_folder=False,
+            packaged_files=[]
         )
     )
 
@@ -490,6 +454,7 @@ async def test_get_staging_paths__job_completed__allows_downloading_all_outputs(
         "input": "HelloWorld.ipynb",
         "ipynb": "output-HelloWorld.ipynb",
         "log": "sagemaker_job_execution.log",
+        "files": []
     }
 
 
@@ -639,8 +604,9 @@ async def test_get_staging_paths__job_failed_with_no_outputs__allows_downloading
 @pytest.mark.asyncio
 @patch.object(InternalMetadataAdapter, "__init__", return_value=None)
 @patch.object(InternalMetadataAdapter, "get_stage", return_value="us-west-2")
+@patch.object(SageMakerScheduler, "get_packaged_file_paths", return_value=[])
 async def test_create_job_for_attched_tags_in_standalone(
-    mock_adapter_stage, mock_adapter_init
+    mock_packaged_files, mock_adapter_stage, mock_adapter_init
 ):
     scheduler = create_scheduler_with_mocked_dependencies()
     scheduler.converter = ModelConverter(MagicMock())
@@ -694,7 +660,9 @@ TEST_CREATE_JOB_IDENTIFIER = "test-job-id"
 )
 @patch.object(InternalMetadataAdapter, "__init__", return_value=None)
 @patch.object(InternalMetadataAdapter, "get_stage", return_value="us-west-2")
+@patch.object(SageMakerScheduler, "get_packaged_file_paths", return_value=[])
 async def test_create_jobdefinition_for_attched_tags_in_standalone(
+    mock_packaged_files,
     mock_adapter_stage,
     mock_metadata_adapter,
     mock_jod_id_generator,
@@ -771,6 +739,62 @@ async def test_create_jobdefinition_for_attched_tags_in_standalone(
     compare_tag_list(event_bridge_rule_tags, expected_tags)
 
 
+@pytest.mark.asyncio
+@patch.object(InternalMetadataAdapter, "__init__", return_value=None)
+@patch.object(InternalMetadataAdapter, "get_stage", return_value="us-west-2")
+@patch.object(SageMakerScheduler, "get_packaged_file_paths", return_value=[])
+async def test_create_job_from_definition_job_id_contains_job_name(
+    mock_packaged_files,
+    mock_adapter_stage,
+    mock_metadata_adapter,
+):
+    # Arrange
+    scheduler = create_scheduler_with_mocked_dependencies()
+    scheduler.converter = ModelConverter(MagicMock())
+
+    job_definition_id = "test-pipeline-id"
+    job_name = "test-job-name"
+    notebook_name = "test-notebook.ipynb"
+
+    # Mock SageMaker client
+    mock_sagemaker_client = AsyncMock()
+    mock_sagemaker_client.describe_pipeline.return_value = {
+        "PipelineDefinition": json.dumps({
+            "Steps": [{
+                "Arguments": {
+                    "Environment": {
+                        JobEnvironmentVariableName.SM_INPUT_NOTEBOOK_NAME.value: notebook_name
+                    },
+                    "Tags": [
+                        {"Key": JobTag.NAME.value, "Value": job_name}
+                    ]
+                }
+            }]
+        })
+    }
+    scheduler._sagemaker_client = mock_sagemaker_client
+
+    # Mock converter methods
+    scheduler.converter.to_tag_dict = MagicMock(return_value={JobTag.NAME.value: job_name})
+    scheduler.converter.generate_training_job_name = MagicMock(
+        return_value=f"{job_name}-{notebook_name}"
+    )
+
+    # Create model and metrics
+    model = CreateJobFromDefinition( )
+    metrics = MetricsContext()
+
+    # Act
+    result_job_id = await scheduler.create_job_from_definition(
+        job_definition_id=job_definition_id,
+        model=model,
+        metrics=metrics
+    )
+
+    # Assert
+    assert job_name in result_job_id, f"Expected job_id '{result_job_id}' to contain job_name '{job_name}'"
+
+
 query = MagicMock()
 query.status = Status.IN_PROGRESS
 query.job_definition_id = "test-jod-definition-id"
@@ -780,7 +804,6 @@ query.sort_by = None
 query.name = "test-job-name"
 
 expected_common_filters = [
-    {"Name": "Tags.sagemaker:is-scheduling-notebook-job", "Operator": "Exists"},
     {
         "Name": "Tags.sagemaker:is-studio-archived",
         "Operator": "Equals",
@@ -861,18 +884,21 @@ async def test_search_list_jobs_filters_studio(
     ]["Filters"]
     compare_tag_list(
         actual_filters,
-        expected_common_filters
-        + [
-            {
-                "Name": "Tags.sagemaker:user-profile-name",
-                "Operator": "Equals",
-                "Value": TEST_USER_DETAILS_PROFILE.user_id_value,
-            }
-        ],
+        expected_common_filters,
         key_name="Name",
     )
 
 
+@pytest.mark.asyncio
+async def test_list_job_with_max_items_as_zero():
+    scheduler = create_scheduler_with_mocked_dependencies()
+    query = MagicMock()
+    query.max_items = 0
+
+    response = await scheduler.list_jobs(query)
+    assert response.jobs == []
+
+
 @pytest.mark.asyncio
 async def test_prepare_job_artifacts_region_check_same_bucket():
     BUCKET_REGION = "us-west-2"
@@ -895,7 +921,7 @@ async def test_prepare_job_artifacts_region_check_same_bucket():
     ):
         try:
             await scheduler._prepare_job_artifacts(
-                AsyncMock(), "test-training", AsyncMock(), mock_runtime_envs, "/home"
+                AsyncMock(), "test-training", AsyncMock(), mock_runtime_envs, "/home", []
             )
         except Exception as ex:
             assert isinstance(ex, SchedulerError)
@@ -930,7 +956,7 @@ async def test_prepare_job_artifacts_region_check_different_bucket():
     ):
         try:
             await scheduler._prepare_job_artifacts(
-                AsyncMock(), "test-training", AsyncMock(), mock_runtime_envs, "/home"
+                AsyncMock(), "test-training", AsyncMock(), mock_runtime_envs, "/home", []
             )
         except Exception as ex:
             assert isinstance(ex, SchedulerError)
@@ -939,7 +965,6 @@ async def test_prepare_job_artifacts_region_check_different_bucket():
                 == f"S3 bucket {TEST_OUTPUT_S3_BUCKET_NAME} must be in region '{AWS_REGION}', but found in '{OUTPUT_BUCKET_REGION}'"
             )
 
-
 @pytest.mark.asyncio
 async def test_meaningful_error_message_create_job_getbucketlocation():
     scheduler = create_scheduler_with_mocked_dependencies()
@@ -960,12 +985,177 @@ async def test_meaningful_error_message_create_job_getbucketlocation():
         runtime_environment_parameters={
             "s3_input": "s3://mock-bucket/mock-path",
             "s3_output": "s3://mock-bucket/mock-path",
-        },
+        }
     )
     with pytest.raises(SchedulerError) as error:
         await scheduler.create_job(create_job_input)
 
     assert (
         str(error.value)
-        == f"AccessDenied: Access Denied, operation: GetBucketLocation, GetBucketLocation failed for {{'mock-bucket'}}, {ACCESS_DENIED_ERROR_MESSAGE}"
+        == f"AccessDenied: Access Denied, operation: GetBucketLocation. Failed to verify bucket location and owner for {{'mock-bucket'}}, {ACCESS_DENIED_ERROR_MESSAGE}"
     )
+
+
+class TestHandleAwsClientError:
+    @pytest.fixture
+    def scheduler(self):
+        # Create a mock scheduler instance with a mock logger
+        scheduler = create_scheduler_with_mocked_dependencies()
+        return scheduler
+
+    @pytest.fixture
+    def sample_boto_error(self):
+        return botocore.exceptions.ClientError(
+            error_response={
+                'Error': {
+                    'Code': 'ValidationError',
+                    'Message': 'Sample boto error'
+                }
+            },
+            operation_name='TestOperation'
+        )
+
+    def test_scheduler_error_handling(self, scheduler):
+        """Test handling of SchedulerError"""
+        scheduler_error = SchedulerError("Test scheduler error")
+
+        with pytest.raises(SchedulerError) as exc_info:
+            scheduler.handle_aws_client_error(scheduler_error)
+
+        assert exc_info.value == scheduler_error
+        # Verify no logging occurred
+        scheduler.log.error.assert_not_called()
+
+    @pytest.mark.parametrize("log_message", [
+        None,
+        "Custom error message",
+        "Error during SageMaker operation"
+    ])
+    def test_boto_client_error_handling(self, scheduler, sample_boto_error, log_message):
+        """Test handling of boto ClientError with different log messages"""
+        with pytest.raises(SageMakerSchedulerError) as exc_info:
+            scheduler.handle_aws_client_error(sample_boto_error, log_message)
+
+        if log_message is not None:
+            scheduler.log.error.assert_called_once_with(
+                f"[SageMakerScheduler] Boto client Error: {log_message}"
+            )
+        else:
+            scheduler.log.error.assert_not_called()
+
+        assert isinstance(exc_info.value, SageMakerSchedulerError)
+
+    @pytest.mark.parametrize("error_code,error_message", [
+        ("ResourceNotFound", "Resource not found"),
+        ("ValidationError", "Invalid parameter value"),
+        ("AccessDenied", "Access denied"),
+        ("ThrottlingException", "Request was throttled")
+    ])
+    def test_different_boto_error_types(self, scheduler, error_code, error_message):
+        """Test handling of different types of boto ClientErrors"""
+        boto_error = botocore.exceptions.ClientError(
+            error_response={
+                'Error': {
+                    'Code': error_code,
+                    'Message': error_message
+                }
+            },
+            operation_name='TestOperation'
+        )
+
+        with pytest.raises(SageMakerSchedulerError) as exc_info:
+            scheduler.handle_aws_client_error(boto_error, f"Error: {error_code}")
+
+        scheduler.log.error.assert_called_once()
+        assert error_code in str(boto_error)
+
+    @pytest.mark.parametrize("runtime_error_msg", [
+        "Generic runtime error",
+        "Operation timeout",
+        "Invalid operation"
+    ])
+    def test_runtime_error_handling(self, scheduler, runtime_error_msg):
+        """Test handling of RuntimeError with different messages"""
+        runtime_error = RuntimeError(runtime_error_msg)
+
+        with pytest.raises(SageMakerSchedulerError) as exc_info:
+            scheduler.handle_aws_client_error(runtime_error, "Runtime error occurred")
+
+        scheduler.log.error.assert_called_once_with(
+            "[SageMakerScheduler] Runtime Error: Runtime error occurred"
+        )
+        assert isinstance(exc_info.value, SageMakerSchedulerError)
+
+    def test_runtime_error_without_message(self, scheduler):
+        """Test handling of RuntimeError without log message"""
+        runtime_error = RuntimeError("Test runtime error")
+
+        with pytest.raises(SageMakerSchedulerError):
+            scheduler.handle_aws_client_error(runtime_error)
+
+        scheduler.log.error.assert_not_called()
+
+    @patch.object(InternalMetadataAdapter, "__init__", return_value=None)
+    @patch.object(InternalMetadataAdapter, "get_app_network_access_type", return_value=MOCK_NETWORK_ACCESS_TYPE)
+    def test_connection_related_errors(self, mock_adapter_network_access_type, mock_adapter_init, scheduler):
+        """Test handling of connection-related boto errors"""
+        # Set up the return value directly on the method chain
+
+        connection_errors = [
+            botocore.exceptions.ConnectTimeoutError(endpoint_url="https://test-endpoint"),
+            botocore.exceptions.EndpointConnectionError(endpoint_url="https://test-endpoint"),
+            botocore.exceptions.ConnectionError(error="Connection refused")
+        ]
+
+        for error in connection_errors:
+            with pytest.raises(SageMakerSchedulerError):
+                scheduler.handle_aws_client_error(error, "Connection error occurred")
+
+            scheduler.log.error.assert_called_with(
+                f"[SageMakerScheduler] {error.__class__.__name__}: Connection error occurred"
+            )
+            scheduler.log.error.reset_mock()
+
+    def test_error_with_empty_log_message(self, scheduler, sample_boto_error):
+        """Test handling errors with empty log message"""
+        with pytest.raises(SageMakerSchedulerError):
+            scheduler.handle_aws_client_error(sample_boto_error, "")
+
+        scheduler.log.error.assert_called_once_with(
+            "[SageMakerScheduler] Boto client Error: "
+        )
+
+    @pytest.mark.parametrize("error_instance", [
+        ValueError("Invalid value"),
+        TypeError("Invalid type"),
+        KeyError("Missing key"),
+        IndexError("Index out of range")
+    ])
+    def test_unhandled_error_types(self, scheduler, error_instance):
+        """Test handling of error types not explicitly handled"""
+        with pytest.raises(Exception):
+            scheduler.handle_aws_client_error(error_instance, "Unexpected error")
+
+    def test_nested_boto_errors(self, scheduler):
+        """Test handling of nested boto errors"""
+        nested_error = botocore.exceptions.ClientError(
+            error_response={
+                'Error': {
+                    'Code': 'ValidationError',
+                    'Message': 'Outer error',
+                    'Details': {
+                        'InnerError': {
+                            'Code': 'ResourceNotFound',
+                            'Message': 'Inner error'
+                        }
+                    }
+                }
+            },
+            operation_name='TestOperation'
+        )
+
+        with pytest.raises(SageMakerSchedulerError) as exc_info:
+            scheduler.handle_aws_client_error(nested_error, "Nested error occurred")
+
+        scheduler.log.error.assert_called_once()
+        assert isinstance(exc_info.value, SageMakerSchedulerError)
