@@ -6,9 +6,14 @@ module.exports = {
   roots: ['<rootDir>/src'],
   moduleFileExtensions: ['ts', 'tsx', 'js', 'jsx', 'json', 'node'],
   setupFilesAfterEnv: [
-    '<rootDir>/setupTests/setupEnzyme.js',
+    '<rootDir>/setupTests/setupTests.js',
     '<rootDir>/setupTests/setupFetch.js',
+    '<rootDir>/setupTests/setupEvents.js',
+    '<rootDir>/setupTests/setupRequestIdleCallback.js',
   ],
+  testEnvironmentOptions:{
+    url: "http://localhost",
+  },
   moduleNameMapper: {
     '\\.(css|less)$': 'identity-obj-proxy',
     '\\.svg$': '<rootDir>/src/__mocks__/fileMock.ts',
