@@ -1,5 +1,7 @@
 from amazon_sagemaker_jupyter_scheduler.scheduler import SageMakerStudioLabScheduler
 from amazon_sagemaker_jupyter_scheduler.environments import SagemakerEnvironmentManager
+from amazon_sagemaker_jupyter_scheduler.file_download_manager import SageMakerJobFilesManager
 
 c.SchedulerApp.scheduler_class = SageMakerStudioLabScheduler
 c.SchedulerApp.environment_manager_class = SagemakerEnvironmentManager
+c.SchedulerApp.job_files_manager_class = SageMakerJobFilesManager
