@@ -1,5 +1,5 @@
 import React from 'react';
-import MuiLink, { LinkProps as MuiLinkProps } from '@material-ui/core/Link';
+import Link, { LinkProps as MuiLinkProps } from '@mui/material/Link';
 import { cx } from '@emotion/css';
 import { LinkUnderline } from './types';
 import { LinkBase } from './styles';
@@ -9,6 +9,8 @@ export interface RouterLinkProps extends MuiLinkProps {
   readonly disabled?: boolean;
   readonly underline?: LinkUnderline;
   readonly to?: string;
+  readonly className?: string;
+  readonly children?: any;
 }
 
 const RouterLink: React.FunctionComponent<RouterLinkProps> = ({ className, children, to, ...materialLinkProps }) => {
@@ -19,7 +21,7 @@ const RouterLink: React.FunctionComponent<RouterLinkProps> = ({ className, child
     component: RouterLinkInt,
   };
 
-  return <MuiLink {...props}>{children}</MuiLink>;
+  return <Link data-testid={'link-to'} {...props}>{children}</Link>;
 };
 
 export { RouterLink };
