@@ -1,5 +1,5 @@
-import { shallow } from 'enzyme';
 import React from 'react';
+import { render, fireEvent } from '@testing-library/react';
 import { Link, LinkProps } from '../Link';
 import { LinkTarget, LinkUnderline } from '../types';
 
@@ -11,24 +11,25 @@ describe('<Link />', () => {
     href,
     underline: LinkUnderline.Hover,
     target: LinkTarget.External,
+    disabled: false,
   };
 
   it('renders correctly with default props', () => {
     const props = { ...defaultProps };
-    const element = shallow(<Link {...props} />);
-
-    expect(element.text()).toBe(children);
-    expect(element.props().href).toBe(href);
+    const { getByTestId } = render(<Link {...props} />);
+    expect(getByTestId('link')).toBeInTheDocument();
   });
 
   it('should handle onClick callback function properly', () => {
-    const mockedClickEvent = { target: {} };
     const onClickHandler = jest.fn();
     const props = { ...defaultProps, onClick: onClickHandler };
-    const element = shallow(<Link {...props} />);
-
-    element.simulate('click', mockedClickEvent);
+    const { getByTestId } = render(<Link {...props} />);
 
+    const link = getByTestId('link');
+    expect(link).toHaveAttribute('rel', 'noopener noreferrer');
+    expect(link).toHaveAttribute('target', '_blank');
+    expect(link).toHaveAttribute('href', 'https://www.amazon.com');
+    fireEvent.click(link);
     expect(onClickHandler).toHaveBeenCalledTimes(1);
   });
 });
