@@ -1,7 +1,7 @@
 import React from 'react';
-import { tooltipStyles } from './styles';
-import MuiTooltip, { TooltipClassKey, TooltipProps as MuiTooltipProps } from '@material-ui/core/Tooltip';
-import { ClassNameMap } from '@material-ui/core/styles/withStyles';
+import { toolTipStyles, toolTipPopperStyles } from './styles';
+import MuiTooltip, { TooltipClassKey, TooltipProps as MuiTooltipProps } from '@mui/material/Tooltip';
+import { ClassNameMap } from '@mui/material';
 import { cx } from '@emotion/css';
 
 enum TooltipPlacements {
@@ -32,13 +32,14 @@ const Tooltip: React.FunctionComponent<TooltipProps> = ({
   placement = TooltipPlacements.Right,
   ...materialTooltipProps
 }) => {
-  const classNames = cx(className, tooltipStyles().popper, classes?.popper);
+  const classNames = cx(className, toolTipPopperStyles(), classes?.popper);
   return (
     <MuiTooltip
       {...materialTooltipProps}
       arrow
-      classes={{ popper: classNames, tooltip: tooltipStyles().tooltip }}
+      classes={{ popper: classNames, tooltip: toolTipStyles() }}
       placement={placement}
+      data-testid={'toolTip'}
     >
       {children}
     </MuiTooltip>
