@@ -1,7 +1,7 @@
 import React, { SyntheticEvent, useState } from 'react';
 import { i18nStrings } from '../../../constants';
 import { Scheduler } from '@jupyterlab/scheduler';
-import { Checkbox } from '@material-ui/core';
+import { Checkbox } from '@mui/material';
 import InfoIcon from '@mui/icons-material/Info';
 import { AutocompleteChangeReason } from '@mui/material/Autocomplete';
 import { InputContainer } from '../InputContainer';
@@ -37,6 +37,7 @@ const errorStrings = i18nStrings.ScheduleNoteBook.MainPanel.ErrorMessages;
 
 const KMSLink = 'https://docs.aws.amazon.com/sagemaker/latest/dg/create-notebook-auto-execution-advanced.html';
 const StartupScriptLink = 'https://aws.amazon.com/blogs/machine-learning/customize-amazon-sagemaker-studio-using-lifecycle-configurations/';
+const NetworkIsolationLink = 'https://docs.aws.amazon.com/sagemaker/latest/APIReference/API_CreateTrainingJob.html#sagemaker-CreateTrainingJob-request-EnableNetworkIsolation';
 
 interface AdvancedOptionProps {
   isDisabled: boolean;
@@ -64,6 +65,15 @@ interface AdvancedOptionProps {
   setEnableVPCSetting: (checkBoxState: boolean) => void;
 }
 
+const networkIsolationTooltipArea = (
+  <div>
+    <span className={Styles.TooltipTextContainer}>{tooltipsStrings.networkIsolationTooltip}</span>
+    <Link href={NetworkIsolationLink} target={LinkTarget.External}>
+      <p className={Styles.TooltipLink}>{tooltipsStrings.LearnMore}</p>
+    </Link>
+  </div>
+);
+
 const kmsTooltipArea = (
   <div>
     <span className={Styles.TooltipTextContainer}>{tooltipsStrings.kmsKeyTooltip}</span>
@@ -109,6 +119,8 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
 }) => {
   const { pluginEnvironment } = usePluginEnvironment();
   const [enableJobEncryption, setEnableJobEncryption] = useState(false);
+  const [useCrossAccountInput, setUseCrossAccountInput] = useState(false);
+  const [useCrossAccountOutput, setUseCrossAccountOutput] = useState(false);
   const [loading, setLoading] = useState(false);
 
   const validateVolumeFilePath = async (filePath: string) => {
@@ -166,9 +178,9 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
   };
 
   const handleMaxRetryAttemptsFieldOnBlur = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
-  		  
+
     const errorMessage = validateMaxRetryAttempts(e.target.value);
- 
+
     setFormValidationErrors({
       ...formErrors,
       maxRetryAttemptsError: errorMessage,
@@ -176,9 +188,9 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
   };
 
   const handleMaxRunTimeInSecondsFieldOnBlur = (e: React.ChangeEvent<HTMLInputElement | HTMLTextAreaElement>) => {
-  		  
+
     const errorMessage = validateMaxRunTimeInSeconds(e.target.value);
- 
+
     setFormValidationErrors({
       ...formErrors,
       maxRunTimeInSecondsError: errorMessage,
@@ -243,7 +255,7 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
         onChange={handleChange}
         value={formState.role_arn}
         onBlur={handleRoleArnOnBlur}
-        toolTipText={pluginEnvironment.isStudio ? studioTooltipsStrings.RoleArnTooltip : tooltipsStrings.RoleArnTooltip}
+        toolTipText={pluginEnvironment.isStudioOrJupyterLab ? studioTooltipsStrings.RoleArnTooltip : tooltipsStrings.RoleArnTooltip}
       />
 
       <InputContainer
@@ -257,8 +269,50 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
         labelInfo={widgetStrings.s3InputFolder}
         errorMessage={formErrors.s3InputFolderError}
         onBlur={handleS3InputFieldOnBlur}
-        toolTipText={pluginEnvironment.isStudio ? studioTooltipsStrings.InputFolderTooltip : tooltipsStrings.InputFolderTooltip}
+        toolTipText={pluginEnvironment.isStudioOrJupyterLab ? studioTooltipsStrings.InputFolderTooltip : tooltipsStrings.InputFolderTooltip}
       />
+      {!isDisabled && (
+        <div className={Styles.TooltipCheckBoxContainer}>
+          <Checkbox
+            data-testid={'input_cross_account_id'}
+            name={'input_cross_account_id'}
+            className={Styles.Checkbox}
+            color={'primary'}
+            checked={useCrossAccountInput}
+            onChange={(e) => {
+              const checkedState = e.target.checked;
+              setUseCrossAccountInput(checkedState);
+              
+              // every time the box is set, account Id resets
+              setFormState({
+                ...formState,
+                s3_input_account_id: '',
+              });
+            }}
+          />
+          <label>{widgetStrings.inputInDifferentAccount}</label>
+        </div>
+      )}
+
+      {(isDisabled || useCrossAccountInput) && (
+        <>
+          <InputContainer
+            name={'s3_input_account_id'}
+            onChange={handleChange}
+            required={false}
+            readOnly={isDisabled}
+            disabled={loading}
+            value={formState.s3_input_account_id}
+            labelInfo={widgetStrings.inputInDifferentAccountLabel}
+            onBlur={(event) => {
+              setFormState({
+                ...formState,
+                s3_input_account_id: event.target.value,
+              });
+            }}
+          />
+        </>
+      )}
       <InputContainer
         name={'s3_output'}
         onChange={handleChange}
@@ -270,8 +324,76 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
         labelInfo={widgetStrings.s3OutputFolder}
         errorMessage={formErrors.s3OutputFolderError}
         onBlur={handleS3InputFieldOnBlur}
-        toolTipText={pluginEnvironment.isStudio ? studioTooltipsStrings.OutputFolderTooltip : tooltipsStrings.OutputFolderTooltip}
+        toolTipText={pluginEnvironment.isStudioOrJupyterLab ? studioTooltipsStrings.OutputFolderTooltip : tooltipsStrings.OutputFolderTooltip}
       />
+      {!isDisabled && (
+        <div className={Styles.TooltipCheckBoxContainer}>
+          <Checkbox
+            data-testid={'output_cross_account_id'}
+            name={'output_cross_account_id'}
+            className={Styles.Checkbox}
+            color={'primary'}
+            checked={useCrossAccountOutput}
+            onChange={(e) => {
+              const checkedState = e.target.checked;
+              setUseCrossAccountOutput(checkedState);
+              
+              // every time the box is set, account Id resets
+              setFormState({
+                ...formState,
+                s3_output_account_id: '',
+              });
+            }}
+          />
+          <label>{widgetStrings.outputInDifferentAccount}</label>
+        </div>
+      )}
+
+      {(isDisabled || useCrossAccountOutput) && (
+        <>
+          <InputContainer
+            name={'s3_output_account_id'}
+            onChange={handleChange}
+            required={false}
+            readOnly={isDisabled}
+            disabled={loading}
+            value={formState.s3_output_account_id}
+            labelInfo={widgetStrings.outputInDifferentAccountLabel}
+            onBlur={(event) => {
+              setFormState({
+                ...formState,
+                s3_output_account_id: event.target.value,
+              });
+            }}
+          />
+        </>
+      )}
+
+      <div className={Styles.TooltipCheckBoxContainer}>
+        <Checkbox
+          data-testid={'enable_network_isolation_checkbox'}
+          name={'enable_network_isolation_checkbox'}
+          className={Styles.Checkbox}
+          color={'primary'}
+          disabled={isDisabled}
+          checked={formState.enable_network_isolation}
+          onChange={(event) => {
+            setFormState({
+              ...formState,
+              enable_network_isolation: event.target.checked
+            });
+          }}
+        />
+        <label>{widgetStrings.enableNetworkIsolation}</label>
+        <Tooltip
+          classes={{
+            popperInteractive: Styles.PopperInteractive,
+          }}
+          title={networkIsolationTooltipArea}
+        >
+          <InfoIcon fontSize="small" />
+        </Tooltip>
+      </div>
 
       {!isDisabled && (
         <div className={Styles.TooltipCheckBoxContainer}>
@@ -307,7 +429,6 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
               popperInteractive: Styles.PopperInteractive,
             }}
             title={kmsTooltipArea}
-            interactive
           >
             <InfoIcon fontSize="small" />
           </Tooltip>
@@ -365,7 +486,7 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
           <MultiSelectContainer
             required
             name={'vpc_subnets'}
-            disabled={isDisabled || availableSubnets.length === 0}
+            disabled={isDisabled || (pluginEnvironment.isStudioOrJupyterLab && availableSubnets.length === 0)}
             label={widgetStrings.subnet}
             options={availableSubnets}
             value={formState.vpc_subnets}
@@ -381,7 +502,7 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
             required
             className={'securityGroupSelector'}
             name={'vpc_security_group_ids'}
-            disabled={isDisabled || availableSubnets.length === 0}
+            disabled={isDisabled || (pluginEnvironment.isStudioOrJupyterLab && availableSecurityGroups.length === 0)}
             label={widgetStrings.securityGroup}
             options={availableSecurityGroups}
             value={formState.vpc_security_group_ids}
@@ -395,12 +516,12 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
         </>
       )}
 
-      {pluginEnvironment.isStudio && <div className={Styles.AdvancedOptionsSelectContainer}>
+      {pluginEnvironment.isStudioOrJupyterLab && <div className={Styles.AdvancedOptionsSelectContainer}>
         <InputLabel id="startup-script-select-label">
           {widgetStrings.startUpScript}
           <Tooltip
             title={startupScriptTooltipContent}
-            interactive>
+          >
             <InfoIcon fontSize="small" />
           </Tooltip>
         </InputLabel>
@@ -438,7 +559,7 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
           errorMessage={formErrors.efsFilePathError}
           onChange={handleChange}
           onBlur={validateInitScript}
-          toolTipText={!isDisabled ? ( pluginEnvironment.isStudio ? studioTooltipsStrings.InitialScriptTooltip : tooltipsStrings.InitialScriptTooltip) : undefined}
+          toolTipText={!isDisabled ? (pluginEnvironment.isStudio ? studioTooltipsStrings.InitialScriptTooltip : tooltipsStrings.InitialScriptTooltip) : undefined}
         />
         {/* {loading && <ActivityIndicator />} */}
       </div>
@@ -459,18 +580,18 @@ const AdvancedOptions: React.FunctionComponent<AdvancedOptionProps> = ({
       />
 
       <InputContainer
-          name={'max_run_time_in_seconds'}
-          type="number"
-          onChange={handleNumberValueChange}
-          required
-          disabled={loading}
-          readOnly={isDisabled}
-          value={formState.max_run_time_in_seconds}
-          placeholder={widgetStrings.maxRunTimeInSeconds}
-          labelInfo={widgetStrings.maxRunTimeInSeconds}
-          errorMessage={formErrors.maxRunTimeInSecondsError}
-          onBlur={handleMaxRunTimeInSecondsFieldOnBlur}
-          toolTipText={tooltipsStrings.MaxRunTimeInSeconds}
+        name={'max_run_time_in_seconds'}
+        type="number"
+        onChange={handleNumberValueChange}
+        required
+        disabled={loading}
+        readOnly={isDisabled}
+        value={formState.max_run_time_in_seconds}
+        placeholder={widgetStrings.maxRunTimeInSeconds}
+        labelInfo={widgetStrings.maxRunTimeInSeconds}
+        errorMessage={formErrors.maxRunTimeInSecondsError}
+        onBlur={handleMaxRunTimeInSecondsFieldOnBlur}
+        toolTipText={tooltipsStrings.MaxRunTimeInSeconds}
       />
 
     </div>
